@@ -110,7 +110,7 @@ ctx = _Context
 def set_request_id(request: Request, response: Response):
     cloud_trace_context = request.get_header(_TRACE_CONTEXT_HEADER_NAME, None)
 
-    if not cloud_trace_context is None:
+    if cloud_trace_context is None:
         ctx.trace_id = str(uuid4())
         ctx.span_id = str(random.randint(1000000000000000000, 9999999999999999999))
         ctx.trace_flags = 'o=1'
